@@ -217,7 +217,7 @@ class Configuration(object):
                         'ss': {'init_size', 'local_min_limit', 'reserve_size'},
                         'mh': {'step_size', 'burn_in', 'sample_every', 'output_hist_every', 'hist_bins',
                                 'credible_intervals', 'beta', 'beta_range', 'exchange_every', 'beta_max', 'cooling',
-                                'crossover_number', 'zeta', 'lambda', 'gamma_prob', 'adaptive', 'time_length', 'graph_stuff'},
+                                'crossover_number', 'zeta', 'lambda', 'gamma_prob', 'adaptive', 'time_length'},
                         'sim': {'simplex_step', 'simplex_log_step', 'simplex_reflection', 'simplex_expansion',
                                 'simplex_contraction', 'simplex_shrink', 'simplex_max_iterations',
                                 'simplex_stop_tol'}
